@@ -17,7 +17,7 @@ use JSON;
 use Lemonldap::NG::Common::Conf::Constants;
 use Lemonldap::NG::Common::PSGI::Constants;
 
-our $VERSION = '2.0.14';
+our $VERSION = '2.0.15';
 
 extends qw(
   Lemonldap::NG::Handler::PSGI::Router
@@ -66,7 +66,7 @@ sub init {
         my @res = ( "Lemonldap::NG::Manager::" . ucfirst($_) );
         if ( my $tmp = $self->loadPlugin( @res, $conf ) ) {
             $self->logger->debug("Plugin $_ loaded");
-            push @links, $_;
+            push @links,                    $_;
             push @{ $self->loadedPlugins }, $tmp;
             $self->hLoadedPlugins->{$_} = $tmp;
         }
@@ -167,7 +167,11 @@ sub tplParams {
     my $res = eval {
         $self->hLoadedPlugins->{viewer}->brwRule->( $req, $req->{userData} );
     } || 0;
-    return ( VERSION => $VERSION, ALLOWBROWSER => $res );
+    return (
+        VERSION      => $VERSION,
+        ALLOWBROWSER => $res,
+        DOC_PREFIX   => ( $self->{docPrefix} || '/doc' ),
+    );
 }
 
 sub javascript {
@@ -183,10 +187,9 @@ sub javascript {
 
     return
 'var formPrefix=staticPrefix+"forms/";var confPrefix=scriptname+"confs/";var viewPrefix=scriptname+"view/";'
-      . 'var allowDiff=' . "$res;"
-      . 'var impPrefix=' . "'"
-      . $impPrefix . "'" . ';'
-      . 'var sessionTTL=' . "$ttl;"
+      . "var allowDiff=$res;"
+      . "var sessionTTL=$ttl;"
+      . "var impPrefix='$impPrefix';"
       . ( $self->links ? 'var links=' . to_json( $self->links ) . ';' : '' )
       . (
         $self->menuLinks
