@@ -15,7 +15,6 @@ extends qw(
   Lemonldap::NG::Common::Conf::AccessLib
 );
 
-use constant _2FTYPES => [ "UBK", "U2F", "TOTP", "WebAuthn" ];
 our $VERSION = '2.0.10';
 
 #############################
@@ -29,7 +28,7 @@ sub init {
 
     # Remote Procedure are defined in Lemonldap::NG::Common::Session::REST
     # HTML template
-    $self->addRoute( '2ndfa.html', undef, ['GET'] )
+    $self->addRoute( '2ndfa.html', 'sfaView', ['GET'] )
 
       ->addRoute(
         sfa => { ':sessionType' => 'sfa' },
@@ -47,8 +46,11 @@ sub init {
     $self->{hiddenAttributes} //= "_password";
     $self->{hiddenAttributes} .= ' _session_id'
       unless $conf->{displaySessionId};
-    $self->{TOTPCheck} = $self->{U2FCheck} = $self->{UBKCheck} =
-      $self->{WebAuthnCheck} = '1';
+
+    $self->{regSfaTypes} = [
+        sort map { s/^Yubikey$/UBK/r } split /[\s,]+/,
+        $conf->{available2FSelfRegistration}
+    ];
     return 1;
 }
 
@@ -69,14 +71,9 @@ sub del2F {
     my $epoch = $params->{epoch}
       or return $self->sendError( $req, 'Missing "epoch" parameter', 400 );
 
-    if ( grep { $_ eq $type } @{ _2FTYPES() } ) {
-        $self->logger->debug(
-            "Call procedure delete2F with type=$type and epoch=$epoch");
-        return $self->delete2F( $req, $session, $skey );
-    }
-    else {
-        return $self->sendError( $req, 'Bad value "type" parameter', 400 );
-    }
+    $self->logger->debug(
+        "Call procedure delete2F with type=$type and epoch=$epoch");
+    return $self->delete2F( $req, $session, $skey );
 }
 
 ########################
@@ -118,11 +115,8 @@ sub sfa {
     my $moduleOptions = $mod->{options};
     $moduleOptions->{backend} = $mod->{module};
 
-    # Select 2FA sessions to display
-    foreach ( @{ _2FTYPES() } ) {
-        $self->{ $_ . 'Check' } = delete $params->{ $_ . 'Check' }
-          if ( defined $params->{ $_ . 'Check' } );
-    }
+    my @display_types = $params->get_all('type');
+    $params->remove('type');
 
     my %filters = map {
         my $s = $_;
@@ -190,19 +184,18 @@ sub sfa {
     # Remove sessions without at least one 2F device(s)
     $self->logger->debug(
         "Removing sessions without at least one 2F device(s)...");
-    my $_2f_types_re = join( '|', @{ _2FTYPES() } );
     foreach my $session ( keys %$res ) {
         delete $res->{$session}
           unless ( defined $res->{$session}->{_2fDevices}
-            and $res->{$session}->{_2fDevices} =~
-            /"type":\s*"(?:$_2f_types_re)"/s );
+            and $res->{$session}->{_2fDevices} =~ /"type"/s );
     }
 
-    # Filter 2FA sessions if needed
-    $self->logger->debug("Filtering 2F sessions...");
     my $all = ( keys %$res );
-    foreach ( @{ _2FTYPES() } ) {
-        if ( $self->{ $_ . 'Check' } eq '2' ) {
+
+    # Filter 2FA sessions if needed
+    if (@display_types) {
+        $self->logger->debug("Filtering 2F sessions...");
+        foreach (@display_types) {
             foreach my $session ( keys %$res ) {
                 delete $res->{$session}
                   unless ( defined $res->{$session}->{_2fDevices}
@@ -286,4 +279,14 @@ qq{Use of an uninitialized attribute "$group" to group sessions},
     );
 }
 
+sub sfaView {
+    my ( $self, $req ) = @_;
+    return $self->p->sendHtml(
+        $req, "2ndfa",
+        params => {
+            SFATYPES => [ map { { SFATYPE => $_ } } @{ $self->{regSfaTypes} } ],
+        }
+    );
+}
+
 1;
